@@ -1,7 +1,8 @@
 from django.conf.urls import patterns, url
 
 
-urlpatterns = patterns('email_registration.views',
+urlpatterns = patterns(
+    'email_registration.views',
     url(r'^$',
         'email_registration_form',
         name='email_registration_form'),
